import 'dart:async';

import 'package:flutter/services.dart';




class SunmiPrinter {

  static Map _printerStatus = {
    'ERROR': 'Something went wrong.', 
    'NORMAL': 'Works normally', 
    'ABNORMAL_COMMUNICATION': 'Abnormal communication',
    'OUT_OF_PAPER': 'Out of paper',
    'PREPARING': 'Preparing printer',
    'OVERHEATED': 'Overheated',
    'OPEN_THE_LID': 'Open the lid',
    'PAPER_CUTTER_ABNORMAL': 'The paper cutter is abnormal',
    'PAPER_CUTTER_RECOVERED': 'The paper cutter has been recovered',
    'NO_BLACK_MARK': 'No black mark had been detected',
    'NO_PRINTER_DETECTED': 'No printer had been detected',
    'FAILED_TO_UPGRADE_FIRMWARE': 'Failed to upgrade firmware',
    'EXCEPTION': 'Unknown Error code',
  };


  static const MethodChannel _channel =
      const MethodChannel('sunmi_printer');

  // START call native code from java
  static Future<bool> bindingPrinter() async { 
    final bool status = await _channel.invokeMethod('BIND_PRINTER_SERVICE');
    return status;
  }

  static Future<bool> unbindingPrinter() async { 
    final bool status = await _channel.invokeMethod('UNBIND_PRINTER_SERVICE'); 
    return status;
  }

  static Future<bool> initPrinter() async { 
    final bool status = await _channel.invokeMethod('INIT_PRINTER');
    return status;
  }

  static Future<String> getPrinterStatus() async { 
    final String status = await _channel.invokeMethod('GET_UPDATE_PRINTER');
    final statusMsg = _printerStatus[status];
    return statusMsg;
  }

  static Future<void> printText(String text) async {
    Map<String, dynamic> arguments = <String, dynamic>{"text": text};
    await _channel.invokeMethod("PRINT_TEXT", arguments);
  }

  static Future<void> start() async {
    await _channel.invokeMethod("START");
  }

  static Future<void> commit() async {
    await _channel.invokeMethod("COMMIT_PRINT");
  }

  static Future<void> cancel() async {
    await _channel.invokeMethod("CANCEL");
  }

  // static Future<void> printerSelfCheck() async { 
  //   await _channel.invokeMethod('printerSelfCheck');
  // }

  // static Future<String> getPrinterSerialNo() async { 
  //   final seialNo = await _channel.invokeMethod('getPrinterSerialNo');
  //   return seialNo;
  // }

}
